[前][次][番号順一覧][スレッド一覧]

ruby-changes:54419

From: k0kubun <ko1@a...>
Date: Sat, 29 Dec 2018 19:50:35 +0900 (JST)
Subject: [ruby-changes:54419] k0kubun:r66634 (trunk): test_jit.rb: suppress random test failure

k0kubun	2018-12-29 19:50:31 +0900 (Sat, 29 Dec 2018)

  New Revision: 66634

  https://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=revision&revision=66634

  Log:
    test_jit.rb: suppress random test failure
    
    on mswin RubyCI by Permission Denied.

  Modified files:
    trunk/test/ruby/test_jit.rb
Index: test/ruby/test_jit.rb
===================================================================
--- test/ruby/test_jit.rb	(revision 66633)
+++ test/ruby/test_jit.rb	(revision 66634)
@@ -607,9 +607,9 @@ class TestJIT < Test::Unit::TestCase https://github.com/ruby/ruby/blob/trunk/test/ruby/test_jit.rb#L607
         assert_equal(3, compactions.size, debug_info)
       end
 
-      if appveyor_mswin?
-        # "Permission Denied" error is preventing to remove so file on AppVeyor.
-        warn 'skipped to test directory emptiness in TestJIT#test_unload_units on AppVeyor mswin'
+      if RUBY_PLATFORM.match?(/mswin/)
+        # "Permission Denied" error is preventing to remove so file on AppVeyor/RubyCI.
+        skip 'Removing so file is randomly failing on AppVeyor/RubyCI mswin due to Permission Denied.'
       else
         # verify .o files are deleted on unload_units
         assert_send([Dir, :empty?, dir], debug_info)
@@ -891,10 +891,6 @@ class TestJIT < Test::Unit::TestCase https://github.com/ruby/ruby/blob/trunk/test/ruby/test_jit.rb#L891
 
   private
 
-  def appveyor_mswin?
-    ENV['APPVEYOR'] == 'True' && RUBY_PLATFORM.match?(/mswin/)
-  end
-
   # The shortest way to test one proc
   def assert_compile_once(script, result_inspect:, insns: [])
     if script.match?(/\A\n.+\n\z/m)

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]